@@ -324,8 +324,8 @@ main(int argc, char **argv)
     signal(SIGPIPE, SIG_IGN);
 
     /* Main poll for activity */
-    while (poll(poll_fds, 2, -1) != -1) {
-
+    for (int ret = 0; (ret != -1) || (errno == EINTR); ret = poll(poll_fds, 2, -1)) {
+      
         if (poll_fds[RND_POLLFD].revents & (POLLERR | POLLHUP | POLLNVAL)) {
             syslog(LOG_INFO, "Linux random device poll error");
             break;
